# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import controlclient_pb2 as controlclient__pb2


class ScsControlStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateCache = channel.unary_unary(
                '/control_client.ScsControl/CreateCache',
                request_serializer=controlclient__pb2._CreateCacheRequest.SerializeToString,
                response_deserializer=controlclient__pb2._CreateCacheResponse.FromString,
                )
        self.DeleteCache = channel.unary_unary(
                '/control_client.ScsControl/DeleteCache',
                request_serializer=controlclient__pb2._DeleteCacheRequest.SerializeToString,
                response_deserializer=controlclient__pb2._DeleteCacheResponse.FromString,
                )
        self.ListCaches = channel.unary_unary(
                '/control_client.ScsControl/ListCaches',
                request_serializer=controlclient__pb2._ListCachesRequest.SerializeToString,
                response_deserializer=controlclient__pb2._ListCachesResponse.FromString,
                )
        self.FlushCache = channel.unary_unary(
                '/control_client.ScsControl/FlushCache',
                request_serializer=controlclient__pb2._FlushCacheRequest.SerializeToString,
                response_deserializer=controlclient__pb2._FlushCacheResponse.FromString,
                )
        self.CreateSigningKey = channel.unary_unary(
                '/control_client.ScsControl/CreateSigningKey',
                request_serializer=controlclient__pb2._CreateSigningKeyRequest.SerializeToString,
                response_deserializer=controlclient__pb2._CreateSigningKeyResponse.FromString,
                )
        self.RevokeSigningKey = channel.unary_unary(
                '/control_client.ScsControl/RevokeSigningKey',
                request_serializer=controlclient__pb2._RevokeSigningKeyRequest.SerializeToString,
                response_deserializer=controlclient__pb2._RevokeSigningKeyResponse.FromString,
                )
        self.ListSigningKeys = channel.unary_unary(
                '/control_client.ScsControl/ListSigningKeys',
                request_serializer=controlclient__pb2._ListSigningKeysRequest.SerializeToString,
                response_deserializer=controlclient__pb2._ListSigningKeysResponse.FromString,
                )
        self.CreateIndex = channel.unary_unary(
                '/control_client.ScsControl/CreateIndex',
                request_serializer=controlclient__pb2._CreateIndexRequest.SerializeToString,
                response_deserializer=controlclient__pb2._CreateIndexResponse.FromString,
                )
        self.DeleteIndex = channel.unary_unary(
                '/control_client.ScsControl/DeleteIndex',
                request_serializer=controlclient__pb2._DeleteIndexRequest.SerializeToString,
                response_deserializer=controlclient__pb2._DeleteIndexResponse.FromString,
                )
        self.ListIndexes = channel.unary_unary(
                '/control_client.ScsControl/ListIndexes',
                request_serializer=controlclient__pb2._ListIndexesRequest.SerializeToString,
                response_deserializer=controlclient__pb2._ListIndexesResponse.FromString,
                )
        self.CreateStore = channel.unary_unary(
                '/control_client.ScsControl/CreateStore',
                request_serializer=controlclient__pb2._CreateStoreRequest.SerializeToString,
                response_deserializer=controlclient__pb2._CreateStoreResponse.FromString,
                )
        self.DeleteStore = channel.unary_unary(
                '/control_client.ScsControl/DeleteStore',
                request_serializer=controlclient__pb2._DeleteStoreRequest.SerializeToString,
                response_deserializer=controlclient__pb2._DeleteStoreResponse.FromString,
                )
        self.ListStores = channel.unary_unary(
                '/control_client.ScsControl/ListStores',
                request_serializer=controlclient__pb2._ListStoresRequest.SerializeToString,
                response_deserializer=controlclient__pb2._ListStoresResponse.FromString,
                )


class ScsControlServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateCache(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCache(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCaches(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FlushCache(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSigningKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeSigningKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSigningKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIndexes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListStores(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ScsControlServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateCache': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCache,
                    request_deserializer=controlclient__pb2._CreateCacheRequest.FromString,
                    response_serializer=controlclient__pb2._CreateCacheResponse.SerializeToString,
            ),
            'DeleteCache': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCache,
                    request_deserializer=controlclient__pb2._DeleteCacheRequest.FromString,
                    response_serializer=controlclient__pb2._DeleteCacheResponse.SerializeToString,
            ),
            'ListCaches': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCaches,
                    request_deserializer=controlclient__pb2._ListCachesRequest.FromString,
                    response_serializer=controlclient__pb2._ListCachesResponse.SerializeToString,
            ),
            'FlushCache': grpc.unary_unary_rpc_method_handler(
                    servicer.FlushCache,
                    request_deserializer=controlclient__pb2._FlushCacheRequest.FromString,
                    response_serializer=controlclient__pb2._FlushCacheResponse.SerializeToString,
            ),
            'CreateSigningKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSigningKey,
                    request_deserializer=controlclient__pb2._CreateSigningKeyRequest.FromString,
                    response_serializer=controlclient__pb2._CreateSigningKeyResponse.SerializeToString,
            ),
            'RevokeSigningKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeSigningKey,
                    request_deserializer=controlclient__pb2._RevokeSigningKeyRequest.FromString,
                    response_serializer=controlclient__pb2._RevokeSigningKeyResponse.SerializeToString,
            ),
            'ListSigningKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSigningKeys,
                    request_deserializer=controlclient__pb2._ListSigningKeysRequest.FromString,
                    response_serializer=controlclient__pb2._ListSigningKeysResponse.SerializeToString,
            ),
            'CreateIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIndex,
                    request_deserializer=controlclient__pb2._CreateIndexRequest.FromString,
                    response_serializer=controlclient__pb2._CreateIndexResponse.SerializeToString,
            ),
            'DeleteIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIndex,
                    request_deserializer=controlclient__pb2._DeleteIndexRequest.FromString,
                    response_serializer=controlclient__pb2._DeleteIndexResponse.SerializeToString,
            ),
            'ListIndexes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIndexes,
                    request_deserializer=controlclient__pb2._ListIndexesRequest.FromString,
                    response_serializer=controlclient__pb2._ListIndexesResponse.SerializeToString,
            ),
            'CreateStore': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStore,
                    request_deserializer=controlclient__pb2._CreateStoreRequest.FromString,
                    response_serializer=controlclient__pb2._CreateStoreResponse.SerializeToString,
            ),
            'DeleteStore': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStore,
                    request_deserializer=controlclient__pb2._DeleteStoreRequest.FromString,
                    response_serializer=controlclient__pb2._DeleteStoreResponse.SerializeToString,
            ),
            'ListStores': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStores,
                    request_deserializer=controlclient__pb2._ListStoresRequest.FromString,
                    response_serializer=controlclient__pb2._ListStoresResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'control_client.ScsControl', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ScsControl(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateCache(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/CreateCache',
            controlclient__pb2._CreateCacheRequest.SerializeToString,
            controlclient__pb2._CreateCacheResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCache(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/DeleteCache',
            controlclient__pb2._DeleteCacheRequest.SerializeToString,
            controlclient__pb2._DeleteCacheResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCaches(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/ListCaches',
            controlclient__pb2._ListCachesRequest.SerializeToString,
            controlclient__pb2._ListCachesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FlushCache(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/FlushCache',
            controlclient__pb2._FlushCacheRequest.SerializeToString,
            controlclient__pb2._FlushCacheResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSigningKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/CreateSigningKey',
            controlclient__pb2._CreateSigningKeyRequest.SerializeToString,
            controlclient__pb2._CreateSigningKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeSigningKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/RevokeSigningKey',
            controlclient__pb2._RevokeSigningKeyRequest.SerializeToString,
            controlclient__pb2._RevokeSigningKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSigningKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/ListSigningKeys',
            controlclient__pb2._ListSigningKeysRequest.SerializeToString,
            controlclient__pb2._ListSigningKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/CreateIndex',
            controlclient__pb2._CreateIndexRequest.SerializeToString,
            controlclient__pb2._CreateIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/DeleteIndex',
            controlclient__pb2._DeleteIndexRequest.SerializeToString,
            controlclient__pb2._DeleteIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIndexes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/ListIndexes',
            controlclient__pb2._ListIndexesRequest.SerializeToString,
            controlclient__pb2._ListIndexesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/CreateStore',
            controlclient__pb2._CreateStoreRequest.SerializeToString,
            controlclient__pb2._CreateStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/DeleteStore',
            controlclient__pb2._DeleteStoreRequest.SerializeToString,
            controlclient__pb2._DeleteStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListStores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/control_client.ScsControl/ListStores',
            controlclient__pb2._ListStoresRequest.SerializeToString,
            controlclient__pb2._ListStoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: controlclient.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ontrolclient.proto\x12\x0e\x63ontrol_client\")\n\x13_CreateStoreRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\x16\n\x14_CreateStoreResponse\")\n\x13_DeleteStoreRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteStoreResponse\"(\n\x12_ListStoresRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"P\n\x13_ListStoresResponse\x12%\n\x05store\x18\x01 \x03(\x0b\x32\x16.control_client._Store\x12\x12\n\nnext_token\x18\x02 \x01(\t\"\x1c\n\x06_Store\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\xda\x02\n\x11_SimilarityMetric\x12V\n\x14\x65uclidean_similarity\x18\x01 \x01(\x0b\x32\x36.control_client._SimilarityMetric._EuclideanSimilarityH\x00\x12H\n\rinner_product\x18\x02 \x01(\x0b\x32/.control_client._SimilarityMetric._InnerProductH\x00\x12P\n\x11\x63osine_similarity\x18\x03 \x01(\x0b\x32\x33.control_client._SimilarityMetric._CosineSimilarityH\x00\x1a\x16\n\x14_EuclideanSimilarity\x1a\x0f\n\r_InnerProduct\x1a\x13\n\x11_CosineSimilarityB\x13\n\x11similarity_metric\"\x7f\n\x13_CreateIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x16\n\x0enum_dimensions\x18\x02 \x01(\x04\x12<\n\x11similarity_metric\x18\x03 \x01(\x0b\x32!.control_client._SimilarityMetric\"\x16\n\x14_CreateIndexResponse\")\n\x13_DeleteIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteIndexResponse\"\x15\n\x13_ListIndexesRequest\"\xc8\x01\n\x14_ListIndexesResponse\x12<\n\x07indexes\x18\x01 \x03(\x0b\x32+.control_client._ListIndexesResponse._Index\x1ar\n\x06_Index\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x16\n\x0enum_dimensions\x18\x02 \x01(\x04\x12<\n\x11similarity_metric\x18\x03 \x01(\x0b\x32!.control_client._SimilarityMetric\")\n\x13_DeleteCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteCacheResponse\")\n\x13_CreateCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x16\n\x14_CreateCacheResponse\"(\n\x12_ListCachesRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"x\n\x0c_CacheLimits\x12\x18\n\x10max_traffic_rate\x18\x01 \x01(\r\x12\x1b\n\x13max_throughput_kbps\x18\x02 \x01(\r\x12\x18\n\x10max_item_size_kb\x18\x03 \x01(\r\x12\x17\n\x0fmax_ttl_seconds\x18\x04 \x01(\x04\"m\n\x0c_TopicLimits\x12\x18\n\x10max_publish_rate\x18\x01 \x01(\r\x12\x1e\n\x16max_subscription_count\x18\x02 \x01(\r\x12#\n\x1bmax_publish_message_size_kb\x18\x03 \x01(\r\"\x84\x01\n\x06_Cache\x12\x12\n\ncache_name\x18\x01 \x01(\t\x12\x32\n\x0c\x63\x61\x63he_limits\x18\x02 \x01(\x0b\x32\x1c.control_client._CacheLimits\x12\x32\n\x0ctopic_limits\x18\x03 \x01(\x0b\x32\x1c.control_client._TopicLimits\"P\n\x13_ListCachesResponse\x12%\n\x05\x63\x61\x63he\x18\x01 \x03(\x0b\x32\x16.control_client._Cache\x12\x12\n\nnext_token\x18\x02 \x01(\t\"/\n\x18_CreateSigningKeyRequest\x12\x13\n\x0bttl_minutes\x18\x01 \x01(\r\"<\n\x19_CreateSigningKeyResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nexpires_at\x18\x02 \x01(\x04\"*\n\x18_RevokeSigningKeyRequest\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x1b\n\x19_RevokeSigningKeyResponse\"1\n\x0b_SigningKey\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nexpires_at\x18\x02 \x01(\x04\"-\n\x17_ListSigningKeysRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"`\n\x18_ListSigningKeysResponse\x12\x30\n\x0bsigning_key\x18\x01 \x03(\x0b\x32\x1b.control_client._SigningKey\x12\x12\n\nnext_token\x18\x02 \x01(\t\"(\n\x12_FlushCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x15\n\x13_FlushCacheResponse2\xd9\t\n\nScsControl\x12Z\n\x0b\x43reateCache\x12#.control_client._CreateCacheRequest\x1a$.control_client._CreateCacheResponse\"\x00\x12Z\n\x0b\x44\x65leteCache\x12#.control_client._DeleteCacheRequest\x1a$.control_client._DeleteCacheResponse\"\x00\x12W\n\nListCaches\x12\".control_client._ListCachesRequest\x1a#.control_client._ListCachesResponse\"\x00\x12W\n\nFlushCache\x12\".control_client._FlushCacheRequest\x1a#.control_client._FlushCacheResponse\"\x00\x12i\n\x10\x43reateSigningKey\x12(.control_client._CreateSigningKeyRequest\x1a).control_client._CreateSigningKeyResponse\"\x00\x12i\n\x10RevokeSigningKey\x12(.control_client._RevokeSigningKeyRequest\x1a).control_client._RevokeSigningKeyResponse\"\x00\x12\x66\n\x0fListSigningKeys\x12\'.control_client._ListSigningKeysRequest\x1a(.control_client._ListSigningKeysResponse\"\x00\x12Z\n\x0b\x43reateIndex\x12#.control_client._CreateIndexRequest\x1a$.control_client._CreateIndexResponse\"\x00\x12Z\n\x0b\x44\x65leteIndex\x12#.control_client._DeleteIndexRequest\x1a$.control_client._DeleteIndexResponse\"\x00\x12Z\n\x0bListIndexes\x12#.control_client._ListIndexesRequest\x1a$.control_client._ListIndexesResponse\"\x00\x12Z\n\x0b\x43reateStore\x12#.control_client._CreateStoreRequest\x1a$.control_client._CreateStoreResponse\"\x00\x12Z\n\x0b\x44\x65leteStore\x12#.control_client._DeleteStoreRequest\x1a$.control_client._DeleteStoreResponse\"\x00\x12W\n\nListStores\x12\".control_client._ListStoresRequest\x1a#.control_client._ListStoresResponse\"\x00\x42h\n\x13grpc.control_clientP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1cMomento.Protos.ControlClientb\x06proto3')



__CREATESTOREREQUEST = DESCRIPTOR.message_types_by_name['_CreateStoreRequest']
__CREATESTORERESPONSE = DESCRIPTOR.message_types_by_name['_CreateStoreResponse']
__DELETESTOREREQUEST = DESCRIPTOR.message_types_by_name['_DeleteStoreRequest']
__DELETESTORERESPONSE = DESCRIPTOR.message_types_by_name['_DeleteStoreResponse']
__LISTSTORESREQUEST = DESCRIPTOR.message_types_by_name['_ListStoresRequest']
__LISTSTORESRESPONSE = DESCRIPTOR.message_types_by_name['_ListStoresResponse']
__STORE = DESCRIPTOR.message_types_by_name['_Store']
__SIMILARITYMETRIC = DESCRIPTOR.message_types_by_name['_SimilarityMetric']
__SIMILARITYMETRIC__EUCLIDEANSIMILARITY = __SIMILARITYMETRIC.nested_types_by_name['_EuclideanSimilarity']
__SIMILARITYMETRIC__INNERPRODUCT = __SIMILARITYMETRIC.nested_types_by_name['_InnerProduct']
__SIMILARITYMETRIC__COSINESIMILARITY = __SIMILARITYMETRIC.nested_types_by_name['_CosineSimilarity']
__CREATEINDEXREQUEST = DESCRIPTOR.message_types_by_name['_CreateIndexRequest']
__CREATEINDEXRESPONSE = DESCRIPTOR.message_types_by_name['_CreateIndexResponse']
__DELETEINDEXREQUEST = DESCRIPTOR.message_types_by_name['_DeleteIndexRequest']
__DELETEINDEXRESPONSE = DESCRIPTOR.message_types_by_name['_DeleteIndexResponse']
__LISTINDEXESREQUEST = DESCRIPTOR.message_types_by_name['_ListIndexesRequest']
__LISTINDEXESRESPONSE = DESCRIPTOR.message_types_by_name['_ListIndexesResponse']
__LISTINDEXESRESPONSE__INDEX = __LISTINDEXESRESPONSE.nested_types_by_name['_Index']
__DELETECACHEREQUEST = DESCRIPTOR.message_types_by_name['_DeleteCacheRequest']
__DELETECACHERESPONSE = DESCRIPTOR.message_types_by_name['_DeleteCacheResponse']
__CREATECACHEREQUEST = DESCRIPTOR.message_types_by_name['_CreateCacheRequest']
__CREATECACHERESPONSE = DESCRIPTOR.message_types_by_name['_CreateCacheResponse']
__LISTCACHESREQUEST = DESCRIPTOR.message_types_by_name['_ListCachesRequest']
__CACHELIMITS = DESCRIPTOR.message_types_by_name['_CacheLimits']
__TOPICLIMITS = DESCRIPTOR.message_types_by_name['_TopicLimits']
__CACHE = DESCRIPTOR.message_types_by_name['_Cache']
__LISTCACHESRESPONSE = DESCRIPTOR.message_types_by_name['_ListCachesResponse']
__CREATESIGNINGKEYREQUEST = DESCRIPTOR.message_types_by_name['_CreateSigningKeyRequest']
__CREATESIGNINGKEYRESPONSE = DESCRIPTOR.message_types_by_name['_CreateSigningKeyResponse']
__REVOKESIGNINGKEYREQUEST = DESCRIPTOR.message_types_by_name['_RevokeSigningKeyRequest']
__REVOKESIGNINGKEYRESPONSE = DESCRIPTOR.message_types_by_name['_RevokeSigningKeyResponse']
__SIGNINGKEY = DESCRIPTOR.message_types_by_name['_SigningKey']
__LISTSIGNINGKEYSREQUEST = DESCRIPTOR.message_types_by_name['_ListSigningKeysRequest']
__LISTSIGNINGKEYSRESPONSE = DESCRIPTOR.message_types_by_name['_ListSigningKeysResponse']
__FLUSHCACHEREQUEST = DESCRIPTOR.message_types_by_name['_FlushCacheRequest']
__FLUSHCACHERESPONSE = DESCRIPTOR.message_types_by_name['_FlushCacheResponse']
_CreateStoreRequest = _reflection.GeneratedProtocolMessageType('_CreateStoreRequest', (_message.Message,), {
  'DESCRIPTOR' : __CREATESTOREREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateStoreRequest)
  })
_sym_db.RegisterMessage(_CreateStoreRequest)

_CreateStoreResponse = _reflection.GeneratedProtocolMessageType('_CreateStoreResponse', (_message.Message,), {
  'DESCRIPTOR' : __CREATESTORERESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateStoreResponse)
  })
_sym_db.RegisterMessage(_CreateStoreResponse)

_DeleteStoreRequest = _reflection.GeneratedProtocolMessageType('_DeleteStoreRequest', (_message.Message,), {
  'DESCRIPTOR' : __DELETESTOREREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._DeleteStoreRequest)
  })
_sym_db.RegisterMessage(_DeleteStoreRequest)

_DeleteStoreResponse = _reflection.GeneratedProtocolMessageType('_DeleteStoreResponse', (_message.Message,), {
  'DESCRIPTOR' : __DELETESTORERESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._DeleteStoreResponse)
  })
_sym_db.RegisterMessage(_DeleteStoreResponse)

_ListStoresRequest = _reflection.GeneratedProtocolMessageType('_ListStoresRequest', (_message.Message,), {
  'DESCRIPTOR' : __LISTSTORESREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListStoresRequest)
  })
_sym_db.RegisterMessage(_ListStoresRequest)

_ListStoresResponse = _reflection.GeneratedProtocolMessageType('_ListStoresResponse', (_message.Message,), {
  'DESCRIPTOR' : __LISTSTORESRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListStoresResponse)
  })
_sym_db.RegisterMessage(_ListStoresResponse)

_Store = _reflection.GeneratedProtocolMessageType('_Store', (_message.Message,), {
  'DESCRIPTOR' : __STORE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._Store)
  })
_sym_db.RegisterMessage(_Store)

_SimilarityMetric = _reflection.GeneratedProtocolMessageType('_SimilarityMetric', (_message.Message,), {

  '_EuclideanSimilarity' : _reflection.GeneratedProtocolMessageType('_EuclideanSimilarity', (_message.Message,), {
    'DESCRIPTOR' : __SIMILARITYMETRIC__EUCLIDEANSIMILARITY,
    '__module__' : 'controlclient_pb2'
    # @@protoc_insertion_point(class_scope:control_client._SimilarityMetric._EuclideanSimilarity)
    })
  ,

  '_InnerProduct' : _reflection.GeneratedProtocolMessageType('_InnerProduct', (_message.Message,), {
    'DESCRIPTOR' : __SIMILARITYMETRIC__INNERPRODUCT,
    '__module__' : 'controlclient_pb2'
    # @@protoc_insertion_point(class_scope:control_client._SimilarityMetric._InnerProduct)
    })
  ,

  '_CosineSimilarity' : _reflection.GeneratedProtocolMessageType('_CosineSimilarity', (_message.Message,), {
    'DESCRIPTOR' : __SIMILARITYMETRIC__COSINESIMILARITY,
    '__module__' : 'controlclient_pb2'
    # @@protoc_insertion_point(class_scope:control_client._SimilarityMetric._CosineSimilarity)
    })
  ,
  'DESCRIPTOR' : __SIMILARITYMETRIC,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._SimilarityMetric)
  })
_sym_db.RegisterMessage(_SimilarityMetric)
_sym_db.RegisterMessage(_SimilarityMetric._EuclideanSimilarity)
_sym_db.RegisterMessage(_SimilarityMetric._InnerProduct)
_sym_db.RegisterMessage(_SimilarityMetric._CosineSimilarity)

_CreateIndexRequest = _reflection.GeneratedProtocolMessageType('_CreateIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : __CREATEINDEXREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateIndexRequest)
  })
_sym_db.RegisterMessage(_CreateIndexRequest)

_CreateIndexResponse = _reflection.GeneratedProtocolMessageType('_CreateIndexResponse', (_message.Message,), {
  'DESCRIPTOR' : __CREATEINDEXRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateIndexResponse)
  })
_sym_db.RegisterMessage(_CreateIndexResponse)

_DeleteIndexRequest = _reflection.GeneratedProtocolMessageType('_DeleteIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : __DELETEINDEXREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._DeleteIndexRequest)
  })
_sym_db.RegisterMessage(_DeleteIndexRequest)

_DeleteIndexResponse = _reflection.GeneratedProtocolMessageType('_DeleteIndexResponse', (_message.Message,), {
  'DESCRIPTOR' : __DELETEINDEXRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._DeleteIndexResponse)
  })
_sym_db.RegisterMessage(_DeleteIndexResponse)

_ListIndexesRequest = _reflection.GeneratedProtocolMessageType('_ListIndexesRequest', (_message.Message,), {
  'DESCRIPTOR' : __LISTINDEXESREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListIndexesRequest)
  })
_sym_db.RegisterMessage(_ListIndexesRequest)

_ListIndexesResponse = _reflection.GeneratedProtocolMessageType('_ListIndexesResponse', (_message.Message,), {

  '_Index' : _reflection.GeneratedProtocolMessageType('_Index', (_message.Message,), {
    'DESCRIPTOR' : __LISTINDEXESRESPONSE__INDEX,
    '__module__' : 'controlclient_pb2'
    # @@protoc_insertion_point(class_scope:control_client._ListIndexesResponse._Index)
    })
  ,
  'DESCRIPTOR' : __LISTINDEXESRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListIndexesResponse)
  })
_sym_db.RegisterMessage(_ListIndexesResponse)
_sym_db.RegisterMessage(_ListIndexesResponse._Index)

_DeleteCacheRequest = _reflection.GeneratedProtocolMessageType('_DeleteCacheRequest', (_message.Message,), {
  'DESCRIPTOR' : __DELETECACHEREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._DeleteCacheRequest)
  })
_sym_db.RegisterMessage(_DeleteCacheRequest)

_DeleteCacheResponse = _reflection.GeneratedProtocolMessageType('_DeleteCacheResponse', (_message.Message,), {
  'DESCRIPTOR' : __DELETECACHERESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._DeleteCacheResponse)
  })
_sym_db.RegisterMessage(_DeleteCacheResponse)

_CreateCacheRequest = _reflection.GeneratedProtocolMessageType('_CreateCacheRequest', (_message.Message,), {
  'DESCRIPTOR' : __CREATECACHEREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateCacheRequest)
  })
_sym_db.RegisterMessage(_CreateCacheRequest)

_CreateCacheResponse = _reflection.GeneratedProtocolMessageType('_CreateCacheResponse', (_message.Message,), {
  'DESCRIPTOR' : __CREATECACHERESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateCacheResponse)
  })
_sym_db.RegisterMessage(_CreateCacheResponse)

_ListCachesRequest = _reflection.GeneratedProtocolMessageType('_ListCachesRequest', (_message.Message,), {
  'DESCRIPTOR' : __LISTCACHESREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListCachesRequest)
  })
_sym_db.RegisterMessage(_ListCachesRequest)

_CacheLimits = _reflection.GeneratedProtocolMessageType('_CacheLimits', (_message.Message,), {
  'DESCRIPTOR' : __CACHELIMITS,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CacheLimits)
  })
_sym_db.RegisterMessage(_CacheLimits)

_TopicLimits = _reflection.GeneratedProtocolMessageType('_TopicLimits', (_message.Message,), {
  'DESCRIPTOR' : __TOPICLIMITS,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._TopicLimits)
  })
_sym_db.RegisterMessage(_TopicLimits)

_Cache = _reflection.GeneratedProtocolMessageType('_Cache', (_message.Message,), {
  'DESCRIPTOR' : __CACHE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._Cache)
  })
_sym_db.RegisterMessage(_Cache)

_ListCachesResponse = _reflection.GeneratedProtocolMessageType('_ListCachesResponse', (_message.Message,), {
  'DESCRIPTOR' : __LISTCACHESRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListCachesResponse)
  })
_sym_db.RegisterMessage(_ListCachesResponse)

_CreateSigningKeyRequest = _reflection.GeneratedProtocolMessageType('_CreateSigningKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : __CREATESIGNINGKEYREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateSigningKeyRequest)
  })
_sym_db.RegisterMessage(_CreateSigningKeyRequest)

_CreateSigningKeyResponse = _reflection.GeneratedProtocolMessageType('_CreateSigningKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : __CREATESIGNINGKEYRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._CreateSigningKeyResponse)
  })
_sym_db.RegisterMessage(_CreateSigningKeyResponse)

_RevokeSigningKeyRequest = _reflection.GeneratedProtocolMessageType('_RevokeSigningKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : __REVOKESIGNINGKEYREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._RevokeSigningKeyRequest)
  })
_sym_db.RegisterMessage(_RevokeSigningKeyRequest)

_RevokeSigningKeyResponse = _reflection.GeneratedProtocolMessageType('_RevokeSigningKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : __REVOKESIGNINGKEYRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._RevokeSigningKeyResponse)
  })
_sym_db.RegisterMessage(_RevokeSigningKeyResponse)

_SigningKey = _reflection.GeneratedProtocolMessageType('_SigningKey', (_message.Message,), {
  'DESCRIPTOR' : __SIGNINGKEY,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._SigningKey)
  })
_sym_db.RegisterMessage(_SigningKey)

_ListSigningKeysRequest = _reflection.GeneratedProtocolMessageType('_ListSigningKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : __LISTSIGNINGKEYSREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListSigningKeysRequest)
  })
_sym_db.RegisterMessage(_ListSigningKeysRequest)

_ListSigningKeysResponse = _reflection.GeneratedProtocolMessageType('_ListSigningKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : __LISTSIGNINGKEYSRESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._ListSigningKeysResponse)
  })
_sym_db.RegisterMessage(_ListSigningKeysResponse)

_FlushCacheRequest = _reflection.GeneratedProtocolMessageType('_FlushCacheRequest', (_message.Message,), {
  'DESCRIPTOR' : __FLUSHCACHEREQUEST,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._FlushCacheRequest)
  })
_sym_db.RegisterMessage(_FlushCacheRequest)

_FlushCacheResponse = _reflection.GeneratedProtocolMessageType('_FlushCacheResponse', (_message.Message,), {
  'DESCRIPTOR' : __FLUSHCACHERESPONSE,
  '__module__' : 'controlclient_pb2'
  # @@protoc_insertion_point(class_scope:control_client._FlushCacheResponse)
  })
_sym_db.RegisterMessage(_FlushCacheResponse)

_SCSCONTROL = DESCRIPTOR.services_by_name['ScsControl']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023grpc.control_clientP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\034Momento.Protos.ControlClient'
  __CREATESTOREREQUEST._serialized_start=39
  __CREATESTOREREQUEST._serialized_end=80
  __CREATESTORERESPONSE._serialized_start=82
  __CREATESTORERESPONSE._serialized_end=104
  __DELETESTOREREQUEST._serialized_start=106
  __DELETESTOREREQUEST._serialized_end=147
  __DELETESTORERESPONSE._serialized_start=149
  __DELETESTORERESPONSE._serialized_end=171
  __LISTSTORESREQUEST._serialized_start=173
  __LISTSTORESREQUEST._serialized_end=213
  __LISTSTORESRESPONSE._serialized_start=215
  __LISTSTORESRESPONSE._serialized_end=295
  __STORE._serialized_start=297
  __STORE._serialized_end=325
  __SIMILARITYMETRIC._serialized_start=328
  __SIMILARITYMETRIC._serialized_end=674
  __SIMILARITYMETRIC__EUCLIDEANSIMILARITY._serialized_start=593
  __SIMILARITYMETRIC__EUCLIDEANSIMILARITY._serialized_end=615
  __SIMILARITYMETRIC__INNERPRODUCT._serialized_start=617
  __SIMILARITYMETRIC__INNERPRODUCT._serialized_end=632
  __SIMILARITYMETRIC__COSINESIMILARITY._serialized_start=634
  __SIMILARITYMETRIC__COSINESIMILARITY._serialized_end=653
  __CREATEINDEXREQUEST._serialized_start=676
  __CREATEINDEXREQUEST._serialized_end=803
  __CREATEINDEXRESPONSE._serialized_start=805
  __CREATEINDEXRESPONSE._serialized_end=827
  __DELETEINDEXREQUEST._serialized_start=829
  __DELETEINDEXREQUEST._serialized_end=870
  __DELETEINDEXRESPONSE._serialized_start=872
  __DELETEINDEXRESPONSE._serialized_end=894
  __LISTINDEXESREQUEST._serialized_start=896
  __LISTINDEXESREQUEST._serialized_end=917
  __LISTINDEXESRESPONSE._serialized_start=920
  __LISTINDEXESRESPONSE._serialized_end=1120
  __LISTINDEXESRESPONSE__INDEX._serialized_start=1006
  __LISTINDEXESRESPONSE__INDEX._serialized_end=1120
  __DELETECACHEREQUEST._serialized_start=1122
  __DELETECACHEREQUEST._serialized_end=1163
  __DELETECACHERESPONSE._serialized_start=1165
  __DELETECACHERESPONSE._serialized_end=1187
  __CREATECACHEREQUEST._serialized_start=1189
  __CREATECACHEREQUEST._serialized_end=1230
  __CREATECACHERESPONSE._serialized_start=1232
  __CREATECACHERESPONSE._serialized_end=1254
  __LISTCACHESREQUEST._serialized_start=1256
  __LISTCACHESREQUEST._serialized_end=1296
  __CACHELIMITS._serialized_start=1298
  __CACHELIMITS._serialized_end=1418
  __TOPICLIMITS._serialized_start=1420
  __TOPICLIMITS._serialized_end=1529
  __CACHE._serialized_start=1532
  __CACHE._serialized_end=1664
  __LISTCACHESRESPONSE._serialized_start=1666
  __LISTCACHESRESPONSE._serialized_end=1746
  __CREATESIGNINGKEYREQUEST._serialized_start=1748
  __CREATESIGNINGKEYREQUEST._serialized_end=1795
  __CREATESIGNINGKEYRESPONSE._serialized_start=1797
  __CREATESIGNINGKEYRESPONSE._serialized_end=1857
  __REVOKESIGNINGKEYREQUEST._serialized_start=1859
  __REVOKESIGNINGKEYREQUEST._serialized_end=1901
  __REVOKESIGNINGKEYRESPONSE._serialized_start=1903
  __REVOKESIGNINGKEYRESPONSE._serialized_end=1930
  __SIGNINGKEY._serialized_start=1932
  __SIGNINGKEY._serialized_end=1981
  __LISTSIGNINGKEYSREQUEST._serialized_start=1983
  __LISTSIGNINGKEYSREQUEST._serialized_end=2028
  __LISTSIGNINGKEYSRESPONSE._serialized_start=2030
  __LISTSIGNINGKEYSRESPONSE._serialized_end=2126
  __FLUSHCACHEREQUEST._serialized_start=2128
  __FLUSHCACHEREQUEST._serialized_end=2168
  __FLUSHCACHERESPONSE._serialized_start=2170
  __FLUSHCACHERESPONSE._serialized_end=2191
  _SCSCONTROL._serialized_start=2194
  _SCSCONTROL._serialized_end=3435
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cachepubsub.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2
from . import extensions_pb2 as extensions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63\x61\x63hepubsub.proto\x12\x13\x63\x61\x63he_client.pubsub\x1a\x0c\x63ommon.proto\x1a\x10\x65xtensions.proto\"k\n\x0f_PublishRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12/\n\x05value\x18\x03 \x01(\x0b\x32 .cache_client.pubsub._TopicValue:\x04\x80\xb5\x18\x00\"h\n\x14_SubscriptionRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\'\n\x1fresume_at_topic_sequence_number\x18\x03 \x01(\x04:\x04\x80\xb5\x18\x01\"\xc0\x01\n\x11_SubscriptionItem\x12/\n\x04item\x18\x01 \x01(\x0b\x32\x1f.cache_client.pubsub._TopicItemH\x00\x12<\n\rdiscontinuity\x18\x02 \x01(\x0b\x32#.cache_client.pubsub._DiscontinuityH\x00\x12\x34\n\theartbeat\x18\x03 \x01(\x0b\x32\x1f.cache_client.pubsub._HeartbeatH\x00\x42\x06\n\x04kind\"r\n\n_TopicItem\x12\x1d\n\x15topic_sequence_number\x18\x01 \x01(\x04\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .cache_client.pubsub._TopicValue\x12\x14\n\x0cpublisher_id\x18\x03 \x01(\t\"7\n\x0b_TopicValue\x12\x0e\n\x04text\x18\x01 \x01(\tH\x00\x12\x10\n\x06\x62inary\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04kind\"I\n\x0e_Discontinuity\x12\x1b\n\x13last_topic_sequence\x18\x01 \x01(\x04\x12\x1a\n\x12new_topic_sequence\x18\x02 \x01(\x04\"\x0c\n\n_Heartbeat2\xab\x01\n\x06Pubsub\x12?\n\x07Publish\x12$.cache_client.pubsub._PublishRequest\x1a\x0e.common._Empty\x12`\n\tSubscribe\x12).cache_client.pubsub._SubscriptionRequest\x1a&.cache_client.pubsub._SubscriptionItem0\x01\x42r\n\x18grpc.cache_client.pubsubP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02!Momento.Protos.CacheClient.Pubsubb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cachepubsub_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030grpc.cache_client.pubsubP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002!Momento.Protos.CacheClient.Pubsub'
  __PUBLISHREQUEST._options = None
  __PUBLISHREQUEST._serialized_options = b'\200\265\030\000'
  __SUBSCRIPTIONREQUEST._options = None
  __SUBSCRIPTIONREQUEST._serialized_options = b'\200\265\030\001'
  __PUBLISHREQUEST._serialized_start=74
  __PUBLISHREQUEST._serialized_end=181
  __SUBSCRIPTIONREQUEST._serialized_start=183
  __SUBSCRIPTIONREQUEST._serialized_end=287
  __SUBSCRIPTIONITEM._serialized_start=290
  __SUBSCRIPTIONITEM._serialized_end=482
  __TOPICITEM._serialized_start=484
  __TOPICITEM._serialized_end=598
  __TOPICVALUE._serialized_start=600
  __TOPICVALUE._serialized_end=655
  __DISCONTINUITY._serialized_start=657
  __DISCONTINUITY._serialized_end=730
  __HEARTBEAT._serialized_start=732
  __HEARTBEAT._serialized_end=744
  _PUBSUB._serialized_start=747
  _PUBSUB._serialized_end=918
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import vectorindex_pb2 as vectorindex__pb2


class VectorIndexStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpsertItemBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/UpsertItemBatch',
                request_serializer=vectorindex__pb2._UpsertItemBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._UpsertItemBatchResponse.FromString,
                )
        self.DeleteItemBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/DeleteItemBatch',
                request_serializer=vectorindex__pb2._DeleteItemBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._DeleteItemBatchResponse.FromString,
                )
        self.Search = channel.unary_unary(
                '/vectorindex.VectorIndex/Search',
                request_serializer=vectorindex__pb2._SearchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._SearchResponse.FromString,
                )
        self.SearchAndFetchVectors = channel.unary_unary(
                '/vectorindex.VectorIndex/SearchAndFetchVectors',
                request_serializer=vectorindex__pb2._SearchAndFetchVectorsRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._SearchAndFetchVectorsResponse.FromString,
                )
        self.GetItemMetadataBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/GetItemMetadataBatch',
                request_serializer=vectorindex__pb2._GetItemMetadataBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._GetItemMetadataBatchResponse.FromString,
                )
        self.GetItemBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/GetItemBatch',
                request_serializer=vectorindex__pb2._GetItemBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._GetItemBatchResponse.FromString,
                )
        self.CountItems = channel.unary_unary(
                '/vectorindex.VectorIndex/CountItems',
                request_serializer=vectorindex__pb2._CountItemsRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._CountItemsResponse.FromString,
                )


class VectorIndexServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UpsertItemBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteItemBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchAndFetchVectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetItemMetadataBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetItemBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountItems(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VectorIndexServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpsertItemBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertItemBatch,
                    request_deserializer=vectorindex__pb2._UpsertItemBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._UpsertItemBatchResponse.SerializeToString,
            ),
            'DeleteItemBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteItemBatch,
                    request_deserializer=vectorindex__pb2._DeleteItemBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._DeleteItemBatchResponse.SerializeToString,
            ),
            'Search': grpc.unary_unary_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=vectorindex__pb2._SearchRequest.FromString,
                    response_serializer=vectorindex__pb2._SearchResponse.SerializeToString,
            ),
            'SearchAndFetchVectors': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchAndFetchVectors,
                    request_deserializer=vectorindex__pb2._SearchAndFetchVectorsRequest.FromString,
                    response_serializer=vectorindex__pb2._SearchAndFetchVectorsResponse.SerializeToString,
            ),
            'GetItemMetadataBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetItemMetadataBatch,
                    request_deserializer=vectorindex__pb2._GetItemMetadataBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._GetItemMetadataBatchResponse.SerializeToString,
            ),
            'GetItemBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetItemBatch,
                    request_deserializer=vectorindex__pb2._GetItemBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._GetItemBatchResponse.SerializeToString,
            ),
            'CountItems': grpc.unary_unary_rpc_method_handler(
                    servicer.CountItems,
                    request_deserializer=vectorindex__pb2._CountItemsRequest.FromString,
                    response_serializer=vectorindex__pb2._CountItemsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vectorindex.VectorIndex', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VectorIndex(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UpsertItemBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/UpsertItemBatch',
            vectorindex__pb2._UpsertItemBatchRequest.SerializeToString,
            vectorindex__pb2._UpsertItemBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteItemBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/DeleteItemBatch',
            vectorindex__pb2._DeleteItemBatchRequest.SerializeToString,
            vectorindex__pb2._DeleteItemBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/Search',
            vectorindex__pb2._SearchRequest.SerializeToString,
            vectorindex__pb2._SearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchAndFetchVectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/SearchAndFetchVectors',
            vectorindex__pb2._SearchAndFetchVectorsRequest.SerializeToString,
            vectorindex__pb2._SearchAndFetchVectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetItemMetadataBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/GetItemMetadataBatch',
            vectorindex__pb2._GetItemMetadataBatchRequest.SerializeToString,
            vectorindex__pb2._GetItemMetadataBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetItemBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/GetItemBatch',
            vectorindex__pb2._GetItemBatchRequest.SerializeToString,
            vectorindex__pb2._GetItemBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CountItems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/CountItems',
            vectorindex__pb2._CountItemsRequest.SerializeToString,
            vectorindex__pb2._CountItemsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import auth_pb2 as auth__pb2


class AuthStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_stream(
                '/auth.Auth/Login',
                request_serializer=auth__pb2._LoginRequest.SerializeToString,
                response_deserializer=auth__pb2._LoginResponse.FromString,
                )
        self.GenerateApiToken = channel.unary_unary(
                '/auth.Auth/GenerateApiToken',
                request_serializer=auth__pb2._GenerateApiTokenRequest.SerializeToString,
                response_deserializer=auth__pb2._GenerateApiTokenResponse.FromString,
                )
        self.RefreshApiToken = channel.unary_unary(
                '/auth.Auth/RefreshApiToken',
                request_serializer=auth__pb2._RefreshApiTokenRequest.SerializeToString,
                response_deserializer=auth__pb2._RefreshApiTokenResponse.FromString,
                )


class AuthServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateApiToken(self, request, context):
        """api for initially generating api and refresh tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshApiToken(self, request, context):
        """api for programmatically refreshing api and refresh tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Login': grpc.unary_stream_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=auth__pb2._LoginRequest.FromString,
                    response_serializer=auth__pb2._LoginResponse.SerializeToString,
            ),
            'GenerateApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateApiToken,
                    request_deserializer=auth__pb2._GenerateApiTokenRequest.FromString,
                    response_serializer=auth__pb2._GenerateApiTokenResponse.SerializeToString,
            ),
            'RefreshApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshApiToken,
                    request_deserializer=auth__pb2._RefreshApiTokenRequest.FromString,
                    response_serializer=auth__pb2._RefreshApiTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'auth.Auth', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Auth(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/auth.Auth/Login',
            auth__pb2._LoginRequest.SerializeToString,
            auth__pb2._LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/auth.Auth/GenerateApiToken',
            auth__pb2._GenerateApiTokenRequest.SerializeToString,
            auth__pb2._GenerateApiTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/auth.Auth/RefreshApiToken',
            auth__pb2._RefreshApiTokenRequest.SerializeToString,
            auth__pb2._RefreshApiTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
Hit: ECacheResult
Invalid: ECacheResult
Miss: ECacheResult
Ok: ECacheResult

class _DeleteRequest(_message.Message):
    __slots__ = ["cache_key"]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    cache_key: bytes
    def __init__(self, cache_key: _Optional[bytes] = ...) -> None: ...

class _DeleteResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _DictionaryDeleteRequest(_message.Message):
    __slots__ = ["all", "dictionary_name", "some"]
    class All(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class Some(_message.Message):
        __slots__ = ["fields"]
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        fields: _containers.RepeatedScalarFieldContainer[bytes]
        def __init__(self, fields: _Optional[_Iterable[bytes]] = ...) -> None: ...
    ALL_FIELD_NUMBER: _ClassVar[int]
    DICTIONARY_NAME_FIELD_NUMBER: _ClassVar[int]
    SOME_FIELD_NUMBER: _ClassVar[int]
    all: _DictionaryDeleteRequest.All
    dictionary_name: bytes
    some: _DictionaryDeleteRequest.Some
    def __init__(self, dictionary_name: _Optional[bytes] = ..., some: _Optional[_Union[_DictionaryDeleteRequest.Some, _Mapping]] = ..., all: _Optional[_Union[_DictionaryDeleteRequest.All, _Mapping]] = ...) -> None: ...

class _DictionaryDeleteResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _DictionaryFetchRequest(_message.Message):
    __slots__ = ["dictionary_name"]
    DICTIONARY_NAME_FIELD_NUMBER: _ClassVar[int]
    dictionary_name: bytes
    def __init__(self, dictionary_name: _Optional[bytes] = ...) -> None: ...

class _DictionaryFetchResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["items"]
        ITEMS_FIELD_NUMBER: _ClassVar[int]
        items: _containers.RepeatedCompositeFieldContainer[_DictionaryFieldValuePair]
        def __init__(self, items: _Optional[_Iterable[_Union[_DictionaryFieldValuePair, _Mapping]]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _DictionaryFetchResponse._Found
    missing: _DictionaryFetchResponse._Missing
    def __init__(self, found: _Optional[_Union[_DictionaryFetchResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_DictionaryFetchResponse._Missing, _Mapping]] = ...) -> None: ...

class _DictionaryFieldValuePair(_message.Message):
    __slots__ = ["field", "value"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    field: bytes
    value: bytes
    def __init__(self, field: _Optional[bytes] = ..., value: _Optional[bytes] = ...) -> None: ...

class _DictionaryGetRequest(_message.Message):
    __slots__ = ["dictionary_name", "fields"]
    DICTIONARY_NAME_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    dictionary_name: bytes
    fields: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, dictionary_name: _Optional[bytes] = ..., fields: _Optional[_Iterable[bytes]] = ...) -> None: ...

class _DictionaryGetResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _DictionaryGetResponsePart(_message.Message):
        __slots__ = ["cache_body", "result"]
        CACHE_BODY_FIELD_NUMBER: _ClassVar[int]
        RESULT_FIELD_NUMBER: _ClassVar[int]
        cache_body: bytes
        result: ECacheResult
        def __init__(self, result: _Optional[_Union[ECacheResult, str]] = ..., cache_body: _Optional[bytes] = ...) -> None: ...
    class _Found(_message.Message):
        __slots__ = ["items"]
        ITEMS_FIELD_NUMBER: _ClassVar[int]
        items: _containers.RepeatedCompositeFieldContainer[_DictionaryGetResponse._DictionaryGetResponsePart]
        def __init__(self, items: _Optional[_Iterable[_Union[_DictionaryGetResponse._DictionaryGetResponsePart, _Mapping]]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _DictionaryGetResponse._Found
    missing: _DictionaryGetResponse._Missing
    def __init__(self, found: _Optional[_Union[_DictionaryGetResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_DictionaryGetResponse._Missing, _Mapping]] = ...) -> None: ...

class _DictionaryIncrementRequest(_message.Message):
    __slots__ = ["amount", "dictionary_name", "field", "refresh_ttl", "ttl_milliseconds"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DICTIONARY_NAME_FIELD_NUMBER: _ClassVar[int]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    amount: int
    dictionary_name: bytes
    field: bytes
    refresh_ttl: bool
    ttl_milliseconds: int
    def __init__(self, dictionary_name: _Optional[bytes] = ..., field: _Optional[bytes] = ..., amount: _Optional[int] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ...) -> None: ...

class _DictionaryIncrementResponse(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: int
    def __init__(self, value: _Optional[int] = ...) -> None: ...

class _DictionaryLengthRequest(_message.Message):
    __slots__ = ["dictionary_name"]
    DICTIONARY_NAME_FIELD_NUMBER: _ClassVar[int]
    dictionary_name: bytes
    def __init__(self, dictionary_name: _Optional[bytes] = ...) -> None: ...

class _DictionaryLengthResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["length"]
        LENGTH_FIELD_NUMBER: _ClassVar[int]
        length: int
        def __init__(self, length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _DictionaryLengthResponse._Found
    missing: _DictionaryLengthResponse._Missing
    def __init__(self, found: _Optional[_Union[_DictionaryLengthResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_DictionaryLengthResponse._Missing, _Mapping]] = ...) -> None: ...

class _DictionarySetRequest(_message.Message):
    __slots__ = ["dictionary_name", "items", "refresh_ttl", "ttl_milliseconds"]
    DICTIONARY_NAME_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    dictionary_name: bytes
    items: _containers.RepeatedCompositeFieldContainer[_DictionaryFieldValuePair]
    refresh_ttl: bool
    ttl_milliseconds: int
    def __init__(self, dictionary_name: _Optional[bytes] = ..., items: _Optional[_Iterable[_Union[_DictionaryFieldValuePair, _Mapping]]] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ...) -> None: ...

class _DictionarySetResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _GetBatchRequest(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_GetRequest]
    def __init__(self, items: _Optional[_Iterable[_Union[_GetRequest, _Mapping]]] = ...) -> None: ...

class _GetRequest(_message.Message):
    __slots__ = ["cache_key"]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    cache_key: bytes
    def __init__(self, cache_key: _Optional[bytes] = ...) -> None: ...

class _GetResponse(_message.Message):
    __slots__ = ["cache_body", "message", "result"]
    CACHE_BODY_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    cache_body: bytes
    message: str
    result: ECacheResult
    def __init__(self, result: _Optional[_Union[ECacheResult, str]] = ..., cache_body: _Optional[bytes] = ..., message: _Optional[str] = ...) -> None: ...

class _IncrementRequest(_message.Message):
    __slots__ = ["amount", "cache_key", "ttl_milliseconds"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    amount: int
    cache_key: bytes
    ttl_milliseconds: int
    def __init__(self, cache_key: _Optional[bytes] = ..., amount: _Optional[int] = ..., ttl_milliseconds: _Optional[int] = ...) -> None: ...

class _IncrementResponse(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: int
    def __init__(self, value: _Optional[int] = ...) -> None: ...

class _ItemGetTtlRequest(_message.Message):
    __slots__ = ["cache_key"]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    cache_key: bytes
    def __init__(self, cache_key: _Optional[bytes] = ...) -> None: ...

class _ItemGetTtlResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["remaining_ttl_millis"]
        REMAINING_TTL_MILLIS_FIELD_NUMBER: _ClassVar[int]
        remaining_ttl_millis: int
        def __init__(self, remaining_ttl_millis: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ItemGetTtlResponse._Found
    missing: _ItemGetTtlResponse._Missing
    def __init__(self, found: _Optional[_Union[_ItemGetTtlResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ItemGetTtlResponse._Missing, _Mapping]] = ...) -> None: ...

class _ItemGetTypeRequest(_message.Message):
    __slots__ = ["cache_key"]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    cache_key: bytes
    def __init__(self, cache_key: _Optional[bytes] = ...) -> None: ...

class _ItemGetTypeResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class ItemType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class _Found(_message.Message):
        __slots__ = ["item_type"]
        ITEM_TYPE_FIELD_NUMBER: _ClassVar[int]
        item_type: _ItemGetTypeResponse.ItemType
        def __init__(self, item_type: _Optional[_Union[_ItemGetTypeResponse.ItemType, str]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    DICTIONARY: _ItemGetTypeResponse.ItemType
    FOUND_FIELD_NUMBER: _ClassVar[int]
    LIST: _ItemGetTypeResponse.ItemType
    MISSING_FIELD_NUMBER: _ClassVar[int]
    SCALAR: _ItemGetTypeResponse.ItemType
    SET: _ItemGetTypeResponse.ItemType
    SORTED_SET: _ItemGetTypeResponse.ItemType
    found: _ItemGetTypeResponse._Found
    missing: _ItemGetTypeResponse._Missing
    def __init__(self, found: _Optional[_Union[_ItemGetTypeResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ItemGetTypeResponse._Missing, _Mapping]] = ...) -> None: ...

class _KeysExistRequest(_message.Message):
    __slots__ = ["cache_keys"]
    CACHE_KEYS_FIELD_NUMBER: _ClassVar[int]
    cache_keys: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, cache_keys: _Optional[_Iterable[bytes]] = ...) -> None: ...

class _KeysExistResponse(_message.Message):
    __slots__ = ["exists"]
    EXISTS_FIELD_NUMBER: _ClassVar[int]
    exists: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, exists: _Optional[_Iterable[bool]] = ...) -> None: ...

class _ListConcatenateBackRequest(_message.Message):
    __slots__ = ["list_name", "refresh_ttl", "truncate_front_to_size", "ttl_milliseconds", "values"]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    TRUNCATE_FRONT_TO_SIZE_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    list_name: bytes
    refresh_ttl: bool
    truncate_front_to_size: int
    ttl_milliseconds: int
    values: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, list_name: _Optional[bytes] = ..., values: _Optional[_Iterable[bytes]] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ..., truncate_front_to_size: _Optional[int] = ...) -> None: ...

class _ListConcatenateBackResponse(_message.Message):
    __slots__ = ["list_length"]
    LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
    list_length: int
    def __init__(self, list_length: _Optional[int] = ...) -> None: ...

class _ListConcatenateFrontRequest(_message.Message):
    __slots__ = ["list_name", "refresh_ttl", "truncate_back_to_size", "ttl_milliseconds", "values"]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    TRUNCATE_BACK_TO_SIZE_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    list_name: bytes
    refresh_ttl: bool
    truncate_back_to_size: int
    ttl_milliseconds: int
    values: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, list_name: _Optional[bytes] = ..., values: _Optional[_Iterable[bytes]] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ..., truncate_back_to_size: _Optional[int] = ...) -> None: ...

class _ListConcatenateFrontResponse(_message.Message):
    __slots__ = ["list_length"]
    LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
    list_length: int
    def __init__(self, list_length: _Optional[int] = ...) -> None: ...

class _ListEraseRequest(_message.Message):
    __slots__ = ["all", "list_name", "some"]
    class _All(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _ListRanges(_message.Message):
        __slots__ = ["ranges"]
        RANGES_FIELD_NUMBER: _ClassVar[int]
        ranges: _containers.RepeatedCompositeFieldContainer[_ListRange]
        def __init__(self, ranges: _Optional[_Iterable[_Union[_ListRange, _Mapping]]] = ...) -> None: ...
    ALL_FIELD_NUMBER: _ClassVar[int]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    SOME_FIELD_NUMBER: _ClassVar[int]
    all: _ListEraseRequest._All
    list_name: bytes
    some: _ListEraseRequest._ListRanges
    def __init__(self, list_name: _Optional[bytes] = ..., some: _Optional[_Union[_ListEraseRequest._ListRanges, _Mapping]] = ..., all: _Optional[_Union[_ListEraseRequest._All, _Mapping]] = ...) -> None: ...

class _ListEraseResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["list_length"]
        LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
        list_length: int
        def __init__(self, list_length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ListEraseResponse._Found
    missing: _ListEraseResponse._Missing
    def __init__(self, found: _Optional[_Union[_ListEraseResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ListEraseResponse._Missing, _Mapping]] = ...) -> None: ...

class _ListFetchRequest(_message.Message):
    __slots__ = ["exclusive_end", "inclusive_start", "list_name", "unbounded_end", "unbounded_start"]
    EXCLUSIVE_END_FIELD_NUMBER: _ClassVar[int]
    INCLUSIVE_START_FIELD_NUMBER: _ClassVar[int]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_END_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_START_FIELD_NUMBER: _ClassVar[int]
    exclusive_end: int
    inclusive_start: int
    list_name: bytes
    unbounded_end: _common_pb2._Unbounded
    unbounded_start: _common_pb2._Unbounded
    def __init__(self, list_name: _Optional[bytes] = ..., unbounded_start: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., inclusive_start: _Optional[int] = ..., unbounded_end: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., exclusive_end: _Optional[int] = ...) -> None: ...

class _ListFetchResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["values"]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        values: _containers.RepeatedScalarFieldContainer[bytes]
        def __init__(self, values: _Optional[_Iterable[bytes]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ListFetchResponse._Found
    missing: _ListFetchResponse._Missing
    def __init__(self, found: _Optional[_Union[_ListFetchResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ListFetchResponse._Missing, _Mapping]] = ...) -> None: ...

class _ListLengthRequest(_message.Message):
    __slots__ = ["list_name"]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    list_name: bytes
    def __init__(self, list_name: _Optional[bytes] = ...) -> None: ...

class _ListLengthResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["length"]
        LENGTH_FIELD_NUMBER: _ClassVar[int]
        length: int
        def __init__(self, length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ListLengthResponse._Found
    missing: _ListLengthResponse._Missing
    def __init__(self, found: _Optional[_Union[_ListLengthResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ListLengthResponse._Missing, _Mapping]] = ...) -> None: ...

class _ListPopBackRequest(_message.Message):
    __slots__ = ["list_name"]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    list_name: bytes
    def __init__(self, list_name: _Optional[bytes] = ...) -> None: ...

class _ListPopBackResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["back", "list_length"]
        BACK_FIELD_NUMBER: _ClassVar[int]
        LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
        back: bytes
        list_length: int
        def __init__(self, back: _Optional[bytes] = ..., list_length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ListPopBackResponse._Found
    missing: _ListPopBackResponse._Missing
    def __init__(self, found: _Optional[_Union[_ListPopBackResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ListPopBackResponse._Missing, _Mapping]] = ...) -> None: ...

class _ListPopFrontRequest(_message.Message):
    __slots__ = ["list_name"]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    list_name: bytes
    def __init__(self, list_name: _Optional[bytes] = ...) -> None: ...

class _ListPopFrontResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["front", "list_length"]
        FRONT_FIELD_NUMBER: _ClassVar[int]
        LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
        front: bytes
        list_length: int
        def __init__(self, front: _Optional[bytes] = ..., list_length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ListPopFrontResponse._Found
    missing: _ListPopFrontResponse._Missing
    def __init__(self, found: _Optional[_Union[_ListPopFrontResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ListPopFrontResponse._Missing, _Mapping]] = ...) -> None: ...

class _ListPushBackRequest(_message.Message):
    __slots__ = ["list_name", "refresh_ttl", "truncate_front_to_size", "ttl_milliseconds", "value"]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    TRUNCATE_FRONT_TO_SIZE_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    list_name: bytes
    refresh_ttl: bool
    truncate_front_to_size: int
    ttl_milliseconds: int
    value: bytes
    def __init__(self, list_name: _Optional[bytes] = ..., value: _Optional[bytes] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ..., truncate_front_to_size: _Optional[int] = ...) -> None: ...

class _ListPushBackResponse(_message.Message):
    __slots__ = ["list_length"]
    LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
    list_length: int
    def __init__(self, list_length: _Optional[int] = ...) -> None: ...

class _ListPushFrontRequest(_message.Message):
    __slots__ = ["list_name", "refresh_ttl", "truncate_back_to_size", "ttl_milliseconds", "value"]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    TRUNCATE_BACK_TO_SIZE_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    list_name: bytes
    refresh_ttl: bool
    truncate_back_to_size: int
    ttl_milliseconds: int
    value: bytes
    def __init__(self, list_name: _Optional[bytes] = ..., value: _Optional[bytes] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ..., truncate_back_to_size: _Optional[int] = ...) -> None: ...

class _ListPushFrontResponse(_message.Message):
    __slots__ = ["list_length"]
    LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
    list_length: int
    def __init__(self, list_length: _Optional[int] = ...) -> None: ...

class _ListRange(_message.Message):
    __slots__ = ["begin_index", "count"]
    BEGIN_INDEX_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    begin_index: int
    count: int
    def __init__(self, begin_index: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...

class _ListRemoveRequest(_message.Message):
    __slots__ = ["all_elements_with_value", "list_name"]
    ALL_ELEMENTS_WITH_VALUE_FIELD_NUMBER: _ClassVar[int]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    all_elements_with_value: bytes
    list_name: bytes
    def __init__(self, list_name: _Optional[bytes] = ..., all_elements_with_value: _Optional[bytes] = ...) -> None: ...

class _ListRemoveResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["list_length"]
        LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
        list_length: int
        def __init__(self, list_length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ListRemoveResponse._Found
    missing: _ListRemoveResponse._Missing
    def __init__(self, found: _Optional[_Union[_ListRemoveResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ListRemoveResponse._Missing, _Mapping]] = ...) -> None: ...

class _ListRetainRequest(_message.Message):
    __slots__ = ["exclusive_end", "inclusive_start", "list_name", "refresh_ttl", "ttl_milliseconds", "unbounded_end", "unbounded_start"]
    EXCLUSIVE_END_FIELD_NUMBER: _ClassVar[int]
    INCLUSIVE_START_FIELD_NUMBER: _ClassVar[int]
    LIST_NAME_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_END_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_START_FIELD_NUMBER: _ClassVar[int]
    exclusive_end: int
    inclusive_start: int
    list_name: bytes
    refresh_ttl: bool
    ttl_milliseconds: int
    unbounded_end: _common_pb2._Unbounded
    unbounded_start: _common_pb2._Unbounded
    def __init__(self, list_name: _Optional[bytes] = ..., unbounded_start: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., inclusive_start: _Optional[int] = ..., unbounded_end: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., exclusive_end: _Optional[int] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ...) -> None: ...

class _ListRetainResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["list_length"]
        LIST_LENGTH_FIELD_NUMBER: _ClassVar[int]
        list_length: int
        def __init__(self, list_length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _ListRetainResponse._Found
    missing: _ListRetainResponse._Missing
    def __init__(self, found: _Optional[_Union[_ListRetainResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_ListRetainResponse._Missing, _Mapping]] = ...) -> None: ...

class _SetBatchRequest(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_SetRequest]
    def __init__(self, items: _Optional[_Iterable[_Union[_SetRequest, _Mapping]]] = ...) -> None: ...

class _SetContainsRequest(_message.Message):
    __slots__ = ["elements", "set_name"]
    ELEMENTS_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    elements: _containers.RepeatedScalarFieldContainer[bytes]
    set_name: bytes
    def __init__(self, set_name: _Optional[bytes] = ..., elements: _Optional[_Iterable[bytes]] = ...) -> None: ...

class _SetContainsResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["contains"]
        CONTAINS_FIELD_NUMBER: _ClassVar[int]
        contains: _containers.RepeatedScalarFieldContainer[bool]
        def __init__(self, contains: _Optional[_Iterable[bool]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SetContainsResponse._Found
    missing: _SetContainsResponse._Missing
    def __init__(self, found: _Optional[_Union[_SetContainsResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SetContainsResponse._Missing, _Mapping]] = ...) -> None: ...

class _SetDifferenceRequest(_message.Message):
    __slots__ = ["minuend", "set_name", "subtrahend"]
    class _Minuend(_message.Message):
        __slots__ = ["elements"]
        ELEMENTS_FIELD_NUMBER: _ClassVar[int]
        elements: _containers.RepeatedScalarFieldContainer[bytes]
        def __init__(self, elements: _Optional[_Iterable[bytes]] = ...) -> None: ...
    class _Subtrahend(_message.Message):
        __slots__ = ["identity", "set"]
        class _Identity(_message.Message):
            __slots__ = []
            def __init__(self) -> None: ...
        class _Set(_message.Message):
            __slots__ = ["elements"]
            ELEMENTS_FIELD_NUMBER: _ClassVar[int]
            elements: _containers.RepeatedScalarFieldContainer[bytes]
            def __init__(self, elements: _Optional[_Iterable[bytes]] = ...) -> None: ...
        IDENTITY_FIELD_NUMBER: _ClassVar[int]
        SET_FIELD_NUMBER: _ClassVar[int]
        identity: _SetDifferenceRequest._Subtrahend._Identity
        set: _SetDifferenceRequest._Subtrahend._Set
        def __init__(self, set: _Optional[_Union[_SetDifferenceRequest._Subtrahend._Set, _Mapping]] = ..., identity: _Optional[_Union[_SetDifferenceRequest._Subtrahend._Identity, _Mapping]] = ...) -> None: ...
    MINUEND_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    SUBTRAHEND_FIELD_NUMBER: _ClassVar[int]
    minuend: _SetDifferenceRequest._Minuend
    set_name: bytes
    subtrahend: _SetDifferenceRequest._Subtrahend
    def __init__(self, set_name: _Optional[bytes] = ..., minuend: _Optional[_Union[_SetDifferenceRequest._Minuend, _Mapping]] = ..., subtrahend: _Optional[_Union[_SetDifferenceRequest._Subtrahend, _Mapping]] = ...) -> None: ...

class _SetDifferenceResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SetDifferenceResponse._Found
    missing: _SetDifferenceResponse._Missing
    def __init__(self, found: _Optional[_Union[_SetDifferenceResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SetDifferenceResponse._Missing, _Mapping]] = ...) -> None: ...

class _SetFetchRequest(_message.Message):
    __slots__ = ["set_name"]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    set_name: bytes
    def __init__(self, set_name: _Optional[bytes] = ...) -> None: ...

class _SetFetchResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["elements"]
        ELEMENTS_FIELD_NUMBER: _ClassVar[int]
        elements: _containers.RepeatedScalarFieldContainer[bytes]
        def __init__(self, elements: _Optional[_Iterable[bytes]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SetFetchResponse._Found
    missing: _SetFetchResponse._Missing
    def __init__(self, found: _Optional[_Union[_SetFetchResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SetFetchResponse._Missing, _Mapping]] = ...) -> None: ...

class _SetIfNotExistsRequest(_message.Message):
    __slots__ = ["cache_body", "cache_key", "ttl_milliseconds"]
    CACHE_BODY_FIELD_NUMBER: _ClassVar[int]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    cache_body: bytes
    cache_key: bytes
    ttl_milliseconds: int
    def __init__(self, cache_key: _Optional[bytes] = ..., cache_body: _Optional[bytes] = ..., ttl_milliseconds: _Optional[int] = ...) -> None: ...

class _SetIfNotExistsResponse(_message.Message):
    __slots__ = ["not_stored", "stored"]
    class _NotStored(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _Stored(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    NOT_STORED_FIELD_NUMBER: _ClassVar[int]
    STORED_FIELD_NUMBER: _ClassVar[int]
    not_stored: _SetIfNotExistsResponse._NotStored
    stored: _SetIfNotExistsResponse._Stored
    def __init__(self, stored: _Optional[_Union[_SetIfNotExistsResponse._Stored, _Mapping]] = ..., not_stored: _Optional[_Union[_SetIfNotExistsResponse._NotStored, _Mapping]] = ...) -> None: ...

class _SetIfRequest(_message.Message):
    __slots__ = ["absent", "absent_or_equal", "cache_body", "cache_key", "equal", "not_equal", "present", "present_and_not_equal", "ttl_milliseconds"]
    ABSENT_FIELD_NUMBER: _ClassVar[int]
    ABSENT_OR_EQUAL_FIELD_NUMBER: _ClassVar[int]
    CACHE_BODY_FIELD_NUMBER: _ClassVar[int]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    EQUAL_FIELD_NUMBER: _ClassVar[int]
    NOT_EQUAL_FIELD_NUMBER: _ClassVar[int]
    PRESENT_AND_NOT_EQUAL_FIELD_NUMBER: _ClassVar[int]
    PRESENT_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    absent: _common_pb2.Absent
    absent_or_equal: _common_pb2.AbsentOrEqual
    cache_body: bytes
    cache_key: bytes
    equal: _common_pb2.Equal
    not_equal: _common_pb2.NotEqual
    present: _common_pb2.Present
    present_and_not_equal: _common_pb2.PresentAndNotEqual
    ttl_milliseconds: int
    def __init__(self, cache_key: _Optional[bytes] = ..., cache_body: _Optional[bytes] = ..., ttl_milliseconds: _Optional[int] = ..., present: _Optional[_Union[_common_pb2.Present, _Mapping]] = ..., present_and_not_equal: _Optional[_Union[_common_pb2.PresentAndNotEqual, _Mapping]] = ..., absent: _Optional[_Union[_common_pb2.Absent, _Mapping]] = ..., equal: _Optional[_Union[_common_pb2.Equal, _Mapping]] = ..., absent_or_equal: _Optional[_Union[_common_pb2.AbsentOrEqual, _Mapping]] = ..., not_equal: _Optional[_Union[_common_pb2.NotEqual, _Mapping]] = ...) -> None: ...

class _SetIfResponse(_message.Message):
    __slots__ = ["not_stored", "stored"]
    class _NotStored(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _Stored(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    NOT_STORED_FIELD_NUMBER: _ClassVar[int]
    STORED_FIELD_NUMBER: _ClassVar[int]
    not_stored: _SetIfResponse._NotStored
    stored: _SetIfResponse._Stored
    def __init__(self, stored: _Optional[_Union[_SetIfResponse._Stored, _Mapping]] = ..., not_stored: _Optional[_Union[_SetIfResponse._NotStored, _Mapping]] = ...) -> None: ...

class _SetLengthRequest(_message.Message):
    __slots__ = ["set_name"]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    set_name: bytes
    def __init__(self, set_name: _Optional[bytes] = ...) -> None: ...

class _SetLengthResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["length"]
        LENGTH_FIELD_NUMBER: _ClassVar[int]
        length: int
        def __init__(self, length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SetLengthResponse._Found
    missing: _SetLengthResponse._Missing
    def __init__(self, found: _Optional[_Union[_SetLengthResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SetLengthResponse._Missing, _Mapping]] = ...) -> None: ...

class _SetPopRequest(_message.Message):
    __slots__ = ["count", "set_name"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    count: int
    set_name: bytes
    def __init__(self, set_name: _Optional[bytes] = ..., count: _Optional[int] = ...) -> None: ...

class _SetPopResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["elements"]
        ELEMENTS_FIELD_NUMBER: _ClassVar[int]
        elements: _containers.RepeatedScalarFieldContainer[bytes]
        def __init__(self, elements: _Optional[_Iterable[bytes]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SetPopResponse._Found
    missing: _SetPopResponse._Missing
    def __init__(self, found: _Optional[_Union[_SetPopResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SetPopResponse._Missing, _Mapping]] = ...) -> None: ...

class _SetRequest(_message.Message):
    __slots__ = ["cache_body", "cache_key", "ttl_milliseconds"]
    CACHE_BODY_FIELD_NUMBER: _ClassVar[int]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    cache_body: bytes
    cache_key: bytes
    ttl_milliseconds: int
    def __init__(self, cache_key: _Optional[bytes] = ..., cache_body: _Optional[bytes] = ..., ttl_milliseconds: _Optional[int] = ...) -> None: ...

class _SetResponse(_message.Message):
    __slots__ = ["message", "result"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    message: str
    result: ECacheResult
    def __init__(self, result: _Optional[_Union[ECacheResult, str]] = ..., message: _Optional[str] = ...) -> None: ...

class _SetSampleRequest(_message.Message):
    __slots__ = ["limit", "set_name"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    limit: int
    set_name: bytes
    def __init__(self, set_name: _Optional[bytes] = ..., limit: _Optional[int] = ...) -> None: ...

class _SetSampleResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["elements"]
        ELEMENTS_FIELD_NUMBER: _ClassVar[int]
        elements: _containers.RepeatedScalarFieldContainer[bytes]
        def __init__(self, elements: _Optional[_Iterable[bytes]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SetSampleResponse._Found
    missing: _SetSampleResponse._Missing
    def __init__(self, found: _Optional[_Union[_SetSampleResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SetSampleResponse._Missing, _Mapping]] = ...) -> None: ...

class _SetUnionRequest(_message.Message):
    __slots__ = ["elements", "refresh_ttl", "set_name", "ttl_milliseconds"]
    ELEMENTS_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    elements: _containers.RepeatedScalarFieldContainer[bytes]
    refresh_ttl: bool
    set_name: bytes
    ttl_milliseconds: int
    def __init__(self, set_name: _Optional[bytes] = ..., elements: _Optional[_Iterable[bytes]] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ...) -> None: ...

class _SetUnionResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _SortedSetElement(_message.Message):
    __slots__ = ["score", "value"]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    score: float
    value: bytes
    def __init__(self, value: _Optional[bytes] = ..., score: _Optional[float] = ...) -> None: ...

class _SortedSetFetchRequest(_message.Message):
    __slots__ = ["by_index", "by_score", "order", "set_name", "with_scores"]
    class Order(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class _ByIndex(_message.Message):
        __slots__ = ["exclusive_end_index", "inclusive_start_index", "unbounded_end", "unbounded_start"]
        EXCLUSIVE_END_INDEX_FIELD_NUMBER: _ClassVar[int]
        INCLUSIVE_START_INDEX_FIELD_NUMBER: _ClassVar[int]
        UNBOUNDED_END_FIELD_NUMBER: _ClassVar[int]
        UNBOUNDED_START_FIELD_NUMBER: _ClassVar[int]
        exclusive_end_index: int
        inclusive_start_index: int
        unbounded_end: _common_pb2._Unbounded
        unbounded_start: _common_pb2._Unbounded
        def __init__(self, unbounded_start: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., inclusive_start_index: _Optional[int] = ..., unbounded_end: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., exclusive_end_index: _Optional[int] = ...) -> None: ...
    class _ByScore(_message.Message):
        __slots__ = ["count", "max_score", "min_score", "offset", "unbounded_max", "unbounded_min"]
        class _Score(_message.Message):
            __slots__ = ["exclusive", "score"]
            EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
            SCORE_FIELD_NUMBER: _ClassVar[int]
            exclusive: bool
            score: float
            def __init__(self, score: _Optional[float] = ..., exclusive: bool = ...) -> None: ...
        COUNT_FIELD_NUMBER: _ClassVar[int]
        MAX_SCORE_FIELD_NUMBER: _ClassVar[int]
        MIN_SCORE_FIELD_NUMBER: _ClassVar[int]
        OFFSET_FIELD_NUMBER: _ClassVar[int]
        UNBOUNDED_MAX_FIELD_NUMBER: _ClassVar[int]
        UNBOUNDED_MIN_FIELD_NUMBER: _ClassVar[int]
        count: int
        max_score: _SortedSetFetchRequest._ByScore._Score
        min_score: _SortedSetFetchRequest._ByScore._Score
        offset: int
        unbounded_max: _common_pb2._Unbounded
        unbounded_min: _common_pb2._Unbounded
        def __init__(self, unbounded_min: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., min_score: _Optional[_Union[_SortedSetFetchRequest._ByScore._Score, _Mapping]] = ..., unbounded_max: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., max_score: _Optional[_Union[_SortedSetFetchRequest._ByScore._Score, _Mapping]] = ..., offset: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...
    ASCENDING: _SortedSetFetchRequest.Order
    BY_INDEX_FIELD_NUMBER: _ClassVar[int]
    BY_SCORE_FIELD_NUMBER: _ClassVar[int]
    DESCENDING: _SortedSetFetchRequest.Order
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    WITH_SCORES_FIELD_NUMBER: _ClassVar[int]
    by_index: _SortedSetFetchRequest._ByIndex
    by_score: _SortedSetFetchRequest._ByScore
    order: _SortedSetFetchRequest.Order
    set_name: bytes
    with_scores: bool
    def __init__(self, set_name: _Optional[bytes] = ..., order: _Optional[_Union[_SortedSetFetchRequest.Order, str]] = ..., with_scores: bool = ..., by_index: _Optional[_Union[_SortedSetFetchRequest._ByIndex, _Mapping]] = ..., by_score: _Optional[_Union[_SortedSetFetchRequest._ByScore, _Mapping]] = ...) -> None: ...

class _SortedSetFetchResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["values", "values_with_scores"]
        class _Values(_message.Message):
            __slots__ = ["values"]
            VALUES_FIELD_NUMBER: _ClassVar[int]
            values: _containers.RepeatedScalarFieldContainer[bytes]
            def __init__(self, values: _Optional[_Iterable[bytes]] = ...) -> None: ...
        class _ValuesWithScores(_message.Message):
            __slots__ = ["elements"]
            ELEMENTS_FIELD_NUMBER: _ClassVar[int]
            elements: _containers.RepeatedCompositeFieldContainer[_SortedSetElement]
            def __init__(self, elements: _Optional[_Iterable[_Union[_SortedSetElement, _Mapping]]] = ...) -> None: ...
        VALUES_FIELD_NUMBER: _ClassVar[int]
        VALUES_WITH_SCORES_FIELD_NUMBER: _ClassVar[int]
        values: _SortedSetFetchResponse._Found._Values
        values_with_scores: _SortedSetFetchResponse._Found._ValuesWithScores
        def __init__(self, values_with_scores: _Optional[_Union[_SortedSetFetchResponse._Found._ValuesWithScores, _Mapping]] = ..., values: _Optional[_Union[_SortedSetFetchResponse._Found._Values, _Mapping]] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SortedSetFetchResponse._Found
    missing: _SortedSetFetchResponse._Missing
    def __init__(self, found: _Optional[_Union[_SortedSetFetchResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SortedSetFetchResponse._Missing, _Mapping]] = ...) -> None: ...

class _SortedSetGetRankRequest(_message.Message):
    __slots__ = ["order", "set_name", "value"]
    class Order(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ASCENDING: _SortedSetGetRankRequest.Order
    DESCENDING: _SortedSetGetRankRequest.Order
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    order: _SortedSetGetRankRequest.Order
    set_name: bytes
    value: bytes
    def __init__(self, set_name: _Optional[bytes] = ..., value: _Optional[bytes] = ..., order: _Optional[_Union[_SortedSetGetRankRequest.Order, str]] = ...) -> None: ...

class _SortedSetGetRankResponse(_message.Message):
    __slots__ = ["element_rank", "missing"]
    class _RankResponsePart(_message.Message):
        __slots__ = ["rank", "result"]
        RANK_FIELD_NUMBER: _ClassVar[int]
        RESULT_FIELD_NUMBER: _ClassVar[int]
        rank: int
        result: ECacheResult
        def __init__(self, result: _Optional[_Union[ECacheResult, str]] = ..., rank: _Optional[int] = ...) -> None: ...
    class _SortedSetMissing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    ELEMENT_RANK_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    element_rank: _SortedSetGetRankResponse._RankResponsePart
    missing: _SortedSetGetRankResponse._SortedSetMissing
    def __init__(self, element_rank: _Optional[_Union[_SortedSetGetRankResponse._RankResponsePart, _Mapping]] = ..., missing: _Optional[_Union[_SortedSetGetRankResponse._SortedSetMissing, _Mapping]] = ...) -> None: ...

class _SortedSetGetScoreRequest(_message.Message):
    __slots__ = ["set_name", "values"]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    set_name: bytes
    values: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, set_name: _Optional[bytes] = ..., values: _Optional[_Iterable[bytes]] = ...) -> None: ...

class _SortedSetGetScoreResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _SortedSetFound(_message.Message):
        __slots__ = ["elements"]
        ELEMENTS_FIELD_NUMBER: _ClassVar[int]
        elements: _containers.RepeatedCompositeFieldContainer[_SortedSetGetScoreResponse._SortedSetGetScoreResponsePart]
        def __init__(self, elements: _Optional[_Iterable[_Union[_SortedSetGetScoreResponse._SortedSetGetScoreResponsePart, _Mapping]]] = ...) -> None: ...
    class _SortedSetGetScoreResponsePart(_message.Message):
        __slots__ = ["result", "score"]
        RESULT_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        result: ECacheResult
        score: float
        def __init__(self, result: _Optional[_Union[ECacheResult, str]] = ..., score: _Optional[float] = ...) -> None: ...
    class _SortedSetMissing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SortedSetGetScoreResponse._SortedSetFound
    missing: _SortedSetGetScoreResponse._SortedSetMissing
    def __init__(self, found: _Optional[_Union[_SortedSetGetScoreResponse._SortedSetFound, _Mapping]] = ..., missing: _Optional[_Union[_SortedSetGetScoreResponse._SortedSetMissing, _Mapping]] = ...) -> None: ...

class _SortedSetIncrementRequest(_message.Message):
    __slots__ = ["amount", "refresh_ttl", "set_name", "ttl_milliseconds", "value"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    amount: float
    refresh_ttl: bool
    set_name: bytes
    ttl_milliseconds: int
    value: bytes
    def __init__(self, set_name: _Optional[bytes] = ..., value: _Optional[bytes] = ..., amount: _Optional[float] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ...) -> None: ...

class _SortedSetIncrementResponse(_message.Message):
    __slots__ = ["score"]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    score: float
    def __init__(self, score: _Optional[float] = ...) -> None: ...

class _SortedSetLengthByScoreRequest(_message.Message):
    __slots__ = ["exclusive_max", "exclusive_min", "inclusive_max", "inclusive_min", "set_name", "unbounded_max", "unbounded_min"]
    EXCLUSIVE_MAX_FIELD_NUMBER: _ClassVar[int]
    EXCLUSIVE_MIN_FIELD_NUMBER: _ClassVar[int]
    INCLUSIVE_MAX_FIELD_NUMBER: _ClassVar[int]
    INCLUSIVE_MIN_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_MAX_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_MIN_FIELD_NUMBER: _ClassVar[int]
    exclusive_max: float
    exclusive_min: float
    inclusive_max: float
    inclusive_min: float
    set_name: bytes
    unbounded_max: _common_pb2._Unbounded
    unbounded_min: _common_pb2._Unbounded
    def __init__(self, set_name: _Optional[bytes] = ..., inclusive_min: _Optional[float] = ..., exclusive_min: _Optional[float] = ..., unbounded_min: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ..., inclusive_max: _Optional[float] = ..., exclusive_max: _Optional[float] = ..., unbounded_max: _Optional[_Union[_common_pb2._Unbounded, _Mapping]] = ...) -> None: ...

class _SortedSetLengthByScoreResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["length"]
        LENGTH_FIELD_NUMBER: _ClassVar[int]
        length: int
        def __init__(self, length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SortedSetLengthByScoreResponse._Found
    missing: _SortedSetLengthByScoreResponse._Missing
    def __init__(self, found: _Optional[_Union[_SortedSetLengthByScoreResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SortedSetLengthByScoreResponse._Missing, _Mapping]] = ...) -> None: ...

class _SortedSetLengthRequest(_message.Message):
    __slots__ = ["set_name"]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    set_name: bytes
    def __init__(self, set_name: _Optional[bytes] = ...) -> None: ...

class _SortedSetLengthResponse(_message.Message):
    __slots__ = ["found", "missing"]
    class _Found(_message.Message):
        __slots__ = ["length"]
        LENGTH_FIELD_NUMBER: _ClassVar[int]
        length: int
        def __init__(self, length: _Optional[int] = ...) -> None: ...
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    found: _SortedSetLengthResponse._Found
    missing: _SortedSetLengthResponse._Missing
    def __init__(self, found: _Optional[_Union[_SortedSetLengthResponse._Found, _Mapping]] = ..., missing: _Optional[_Union[_SortedSetLengthResponse._Missing, _Mapping]] = ...) -> None: ...

class _SortedSetPutRequest(_message.Message):
    __slots__ = ["elements", "refresh_ttl", "set_name", "ttl_milliseconds"]
    ELEMENTS_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TTL_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    TTL_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    elements: _containers.RepeatedCompositeFieldContainer[_SortedSetElement]
    refresh_ttl: bool
    set_name: bytes
    ttl_milliseconds: int
    def __init__(self, set_name: _Optional[bytes] = ..., elements: _Optional[_Iterable[_Union[_SortedSetElement, _Mapping]]] = ..., ttl_milliseconds: _Optional[int] = ..., refresh_ttl: bool = ...) -> None: ...

class _SortedSetPutResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _SortedSetRemoveRequest(_message.Message):
    __slots__ = ["all", "set_name", "some"]
    class _All(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _Some(_message.Message):
        __slots__ = ["values"]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        values: _containers.RepeatedScalarFieldContainer[bytes]
        def __init__(self, values: _Optional[_Iterable[bytes]] = ...) -> None: ...
    ALL_FIELD_NUMBER: _ClassVar[int]
    SET_NAME_FIELD_NUMBER: _ClassVar[int]
    SOME_FIELD_NUMBER: _ClassVar[int]
    all: _SortedSetRemoveRequest._All
    set_name: bytes
    some: _SortedSetRemoveRequest._Some
    def __init__(self, set_name: _Optional[bytes] = ..., all: _Optional[_Union[_SortedSetRemoveRequest._All, _Mapping]] = ..., some: _Optional[_Union[_SortedSetRemoveRequest._Some, _Mapping]] = ...) -> None: ...

class _SortedSetRemoveResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _UpdateTtlRequest(_message.Message):
    __slots__ = ["cache_key", "decrease_to_milliseconds", "increase_to_milliseconds", "overwrite_to_milliseconds"]
    CACHE_KEY_FIELD_NUMBER: _ClassVar[int]
    DECREASE_TO_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    INCREASE_TO_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    OVERWRITE_TO_MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    cache_key: bytes
    decrease_to_milliseconds: int
    increase_to_milliseconds: int
    overwrite_to_milliseconds: int
    def __init__(self, cache_key: _Optional[bytes] = ..., increase_to_milliseconds: _Optional[int] = ..., decrease_to_milliseconds: _Optional[int] = ..., overwrite_to_milliseconds: _Optional[int] = ...) -> None: ...

class _UpdateTtlResponse(_message.Message):
    __slots__ = ["missing", "not_set", "set"]
    class _Missing(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _NotSet(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _Set(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    MISSING_FIELD_NUMBER: _ClassVar[int]
    NOT_SET_FIELD_NUMBER: _ClassVar[int]
    SET_FIELD_NUMBER: _ClassVar[int]
    missing: _UpdateTtlResponse._Missing
    not_set: _UpdateTtlResponse._NotSet
    set: _UpdateTtlResponse._Set
    def __init__(self, set: _Optional[_Union[_UpdateTtlResponse._Set, _Mapping]] = ..., not_set: _Optional[_Union[_UpdateTtlResponse._NotSet, _Mapping]] = ..., missing: _Optional[_Union[_UpdateTtlResponse._Missing, _Mapping]] = ...) -> None: ...

class ECacheResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import permissionmessages_pb2 as permissionmessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x04\x61uth\x1a\x18permissionmessages.proto\"\x0f\n\r_LoginRequest\"\xfc\x02\n\x0e_LoginResponse\x12<\n\x0e\x64irect_browser\x18\x01 \x01(\x0b\x32\".auth._LoginResponse.DirectBrowserH\x00\x12\x32\n\tlogged_in\x18\x02 \x01(\x0b\x32\x1d.auth._LoginResponse.LoggedInH\x00\x12/\n\x07message\x18\x03 \x01(\x0b\x32\x1c.auth._LoginResponse.MessageH\x00\x12+\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x1a.auth._LoginResponse.ErrorH\x00\x1a<\n\x08LoggedIn\x12\x15\n\rsession_token\x18\x01 \x01(\t\x12\x19\n\x11valid_for_seconds\x18\x02 \x01(\r\x1a\x1c\n\x05\x45rror\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x1a\x1c\n\rDirectBrowser\x12\x0b\n\x03url\x18\x01 \x01(\t\x1a\x17\n\x07Message\x12\x0c\n\x04text\x18\x01 \x01(\tB\x07\n\x05state\"\xb7\x02\n\x18_GenerateApiTokenRequest\x12\x35\n\x05never\x18\x01 \x01(\x0b\x32$.auth._GenerateApiTokenRequest.NeverH\x00\x12\x39\n\x07\x65xpires\x18\x02 \x01(\x0b\x32&.auth._GenerateApiTokenRequest.ExpiresH\x00\x12\x12\n\nauth_token\x18\x03 \x01(\t\x12\x35\n\x0bpermissions\x18\x04 \x01(\x0b\x32 .permission_messages.Permissions\x12\x10\n\x08token_id\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x1a\x07\n\x05Never\x1a$\n\x07\x45xpires\x12\x19\n\x11valid_for_seconds\x18\x01 \x01(\rB\x08\n\x06\x65xpiry\"j\n\x19_GenerateApiTokenResponse\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x13\n\x0bvalid_until\x18\x04 \x01(\x04\"A\n\x17_RefreshApiTokenRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"i\n\x18_RefreshApiTokenResponse\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x13\n\x0bvalid_until\x18\x04 \x01(\x04\x32\xe9\x01\n\x04\x41uth\x12\x36\n\x05Login\x12\x13.auth._LoginRequest\x1a\x14.auth._LoginResponse\"\x00\x30\x01\x12U\n\x10GenerateApiToken\x12\x1e.auth._GenerateApiTokenRequest\x1a\x1f.auth._GenerateApiTokenResponse\"\x00\x12R\n\x0fRefreshApiToken\x12\x1d.auth._RefreshApiTokenRequest\x1a\x1e.auth._RefreshApiTokenResponse\"\x00\x42\x42\n\x0cmomento.authP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_gob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014momento.authP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go'
  __LOGINREQUEST._serialized_start=46
  __LOGINREQUEST._serialized_end=61
  __LOGINRESPONSE._serialized_start=64
  __LOGINRESPONSE._serialized_end=444
  __LOGINRESPONSE_LOGGEDIN._serialized_start=290
  __LOGINRESPONSE_LOGGEDIN._serialized_end=350
  __LOGINRESPONSE_ERROR._serialized_start=352
  __LOGINRESPONSE_ERROR._serialized_end=380
  __LOGINRESPONSE_DIRECTBROWSER._serialized_start=382
  __LOGINRESPONSE_DIRECTBROWSER._serialized_end=410
  __LOGINRESPONSE_MESSAGE._serialized_start=412
  __LOGINRESPONSE_MESSAGE._serialized_end=435
  __GENERATEAPITOKENREQUEST._serialized_start=447
  __GENERATEAPITOKENREQUEST._serialized_end=758
  __GENERATEAPITOKENREQUEST_NEVER._serialized_start=703
  __GENERATEAPITOKENREQUEST_NEVER._serialized_end=710
  __GENERATEAPITOKENREQUEST_EXPIRES._serialized_start=712
  __GENERATEAPITOKENREQUEST_EXPIRES._serialized_end=748
  __GENERATEAPITOKENRESPONSE._serialized_start=760
  __GENERATEAPITOKENRESPONSE._serialized_end=866
  __REFRESHAPITOKENREQUEST._serialized_start=868
  __REFRESHAPITOKENREQUEST._serialized_end=933
  __REFRESHAPITOKENRESPONSE._serialized_start=935
  __REFRESHAPITOKENRESPONSE._serialized_end=1040
  _AUTH._serialized_start=1043
  _AUTH._serialized_end=1276
# @@protoc_insertion_point(module_scope)
